@@ -1,7 +1,7 @@
 """Top-level package for tgsender."""
-from . import api
+from . import api_async
 from .tgsender import get_data_upload_plan, main
 
 __author__ = """apenasrr"""
 __email__ = "apenasrr@gmail.com"
-__version__ = "0.1.3"
+__version__ = "0.1.5"
